@@ -34,6 +34,8 @@
 #include "terminalDisplay/TerminalDisplay.h"
 #include "widgets/ViewContainer.h"
 
+#include "pluginsystem/IKonsolePlugin.h"
+
 using namespace Konsole;
 
 Application::Application(QSharedPointer<QCommandLineParser> parser,
@@ -42,6 +44,7 @@ Application::Application(QSharedPointer<QCommandLineParser> parser,
     m_parser(parser),
     m_customCommand(customCommand)
 {
+    m_pluginManager.loadAllPlugins();
 }
 
 void Application::populateCommandLineParser(QCommandLineParser *parser)
@@ -51,7 +54,11 @@ void Application::populateCommandLineParser(QCommandLineParser *parser)
             i18nc("@info:shell", "Name of profile to use for new Konsole instance"),
             QStringLiteral("name")
         },
-        { { QStringLiteral("fallback-profile") },
+        { { QStringLiteral("layout") },
+            i18nc("@info:shell", "json layoutfile to be loaded to use for new Konsole instance"),
+            QStringLiteral("file")
+        },
+         { { QStringLiteral("fallback-profile") },
             i18nc("@info:shell", "Use the internal FALLBACK profile")
         },
         { { QStringLiteral("workdir") },
@@ -160,6 +167,8 @@ MainWindow *Application::newMainWindow()
             &Konsole::Application::createWindow);
     connect(window, &Konsole::MainWindow::terminalsDetached, this, &Konsole::Application::detachTerminals);
 
+    m_pluginManager.registerMainWindow(window);
+
     return window;
 }
 
@@ -210,7 +219,6 @@ int Application::newInstance()
             return 0;
         }
     }
-
     // select profile to use
     Profile::Ptr baseProfile = processProfileSelectArgs();
 
@@ -218,14 +226,20 @@ int Application::newInstance()
     // selected profile to be changed
     Profile::Ptr newProfile = processProfileChangeArgs(baseProfile);
 
-    // create new session
-    Session *session = window->createSession(newProfile, QString());
+    // if layout file is enable load it and create session from definitions,
+    // else create new session
+    if (m_parser->isSet(QStringLiteral("layout"))) {
+        window->viewManager()->loadLayout(m_parser->value(QStringLiteral("layout")));
+    } else {
+        Session *session = window->createSession(newProfile, QString());
 
-    if (m_parser->isSet(QStringLiteral("noclose"))) {
-        session->setAutoClose(false);
+        if (m_parser->isSet(QStringLiteral("noclose"))) {
+            session->setAutoClose(false);
+        }
     }
 
-    // if the background-mode argument is supplied, start the background
+
+        // if the background-mode argument is supplied, start the background
     // session ( or bring to the front if it already exists )
     if (m_parser->isSet(QStringLiteral("background-mode"))) {
         startBackgroundMode(window);
@@ -294,11 +308,7 @@ bool Application::processTabsFromFileArgs(MainWindow *window)
         }
 
         QHash<QString, QString> lineTokens;
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 15, 0))
         QStringList lineParts = lineString.split(QStringLiteral(";;"), Qt::SkipEmptyParts);
-#else
-        QStringList lineParts = lineString.split(QStringLiteral(";;"), QString::SkipEmptyParts);
-#endif
 
         for (int i = 0; i < lineParts.size(); ++i) {
             QString key = lineParts.at(i).section(QLatin1Char(':'), 0, 0).trimmed().toLower();
