@@ -17,6 +17,7 @@
 #include <KAcceleratorManager>
 #include <KActionCollection>
 #include <KActionMenu>
+#include <KIconUtils>
 #include <KShortcutsDialog>
 #include <KLocalizedString>
 #include <KWindowEffects>
@@ -28,9 +29,9 @@
 #include <KWindowSystem>
 #include <KXMLGUIFactory>
 #include <KNotifyConfigWidget>
-#include <KIconLoader>
 
 #include <kio_version.h>
+#include <kwindowsystem_version.h>
 
 // Konsole
 #include "BookmarkHandler.h"
@@ -129,7 +130,7 @@ MainWindow::MainWindow() :
     KAcceleratorManager::setNoAccel(menuBar());
 
     // create menus
-    setupGUI();
+    createGUI();
 
     // remember the original menu accelerators for later use
     rememberMenuAccelerators();
@@ -377,6 +378,20 @@ void MainWindow::setupActions()
     menuAction->setText(i18nc("@item", "Activate Menu"));
     collection->setDefaultShortcut(menuAction, Konsole::ACCEL | Qt::SHIFT | Qt::Key_F10);
     connect(menuAction, &QAction::triggered, this, &Konsole::MainWindow::activateMenuBar);
+
+    auto action = collection->addAction(QStringLiteral("save-layout"));
+    action->setEnabled(true);
+    action->setText(i18nc("@action:inmenu", "Save tab layout to file"));
+    connect(action, &QAction::triggered, this, [this]() {
+        if (viewManager()) { viewManager()->saveLayoutFile(); }
+    });
+
+    action = collection->addAction(QStringLiteral("load-layout"));
+    action->setEnabled(true);
+    action->setText(i18nc("@action:inmenu", "Load tab layout from file"));
+    connect(action, &QAction::triggered, this, [this]() {
+        if (viewManager()) { viewManager()->loadLayoutFile(); }
+    });
 }
 
 void MainWindow::viewFullScreen(bool fullScreen)
@@ -423,7 +438,7 @@ void MainWindow::profileListChanged(const QList<QAction *> &sessionActions)
 
             Profile::Ptr profile = ProfileManager::instance()->defaultProfile();
             if (profile && profile->name() == sessionAction->text().remove(QLatin1Char('&'))) {
-                QIcon icon(KIconLoader::global()->loadIcon(profile->icon(), KIconLoader::Small, 0, KIconLoader::DefaultState, QStringList(QStringLiteral("emblem-favorite"))));
+                QIcon icon = KIconUtils::addOverlay(QIcon::fromTheme(profile->icon()), QIcon::fromTheme(QStringLiteral("emblem-favorite")), Qt::BottomRightCorner);
                 sessionAction->setIcon(icon);
                 setActionFontBold(true);
             } else {
@@ -480,6 +495,13 @@ void MainWindow::newTab()
     createSession(defaultProfile, activeSessionDir());
 }
 
+void MainWindow::addPlugin(IKonsolePlugin *plugin)
+{
+    _plugins.append(plugin);
+    connect(_viewManager, &Konsole::ViewManager::activeViewChanged, plugin,
+        &IKonsolePlugin::activeViewChanged);
+}
+
 void MainWindow::cloneTab()
 {
     Q_ASSERT(_pluggedController);
@@ -510,6 +532,7 @@ Session *MainWindow::createSession(Profile::Ptr profile, const QString &director
     // don't like this happening
     auto newView = _viewManager->createView(session);
     _viewManager->activeContainer()->addView(newView);
+
     return session;
 }
 
@@ -863,7 +886,11 @@ void MainWindow::setBlur(bool blur)
     _blurEnabled = blur;
 
     if (!_pluggedController->isKonsolePart()) {
+#if KWINDOWSYSTEM_VERSION < QT_VERSION_CHECK(5,82,0)
         KWindowEffects::enableBlurBehind(winId(), blur);
+#else
+        KWindowEffects::enableBlurBehind(windowHandle(), blur);
+#endif
     }
 }
 
@@ -954,11 +981,11 @@ bool MainWindow::eventFilter(QObject *obj, QEvent *event)
     return KXmlGuiWindow::eventFilter(obj, event);
 }
 
-bool MainWindow::focusNextPrevChild(bool)
+bool MainWindow::focusNextPrevChild(bool v)
 {
-    // In stand-alone konsole, always disable implicit focus switching
-    // through 'Tab' and 'Shift+Tab'
-    //
-    // Kpart is another different story
-    return false;
+    if (qobject_cast<TerminalDisplay*>(focusWidget())) {
+        return false;
+    }
+
+    return QMainWindow::focusNextPrevChild(v);
 }
