@@ -8,6 +8,9 @@
 #ifndef SCREEN_H
 #define SCREEN_H
 
+// STD
+#include <memory>
+
 // Qt
 #include <QRect>
 #include <QSet>
@@ -506,10 +509,12 @@ public:
      * LINE_WRAPPED:     Specifies that the line is wrapped.
      * LINE_DOUBLEWIDTH: Specifies that the characters in the current line
      *                   should be double the normal width.
-     * LINE_DOUBLEHEIGHT:Specifies that the characters in the current line
+     * LINE_DOUBLEHEIGHT_TOP:
+     * LINE_DOUBLEHEIGHT_BOTTOM: Specifies that the characters in the current line
      *                   should be double the normal height.
      *                   Double-height lines are formed of two lines containing the same characters,
-     *                   with both having the LINE_DOUBLEHEIGHT attribute.
+     *                   with the top one having the LINE_DOUBLEHEIGHT_TOP attribute
+     *                   and the bottom one having the LINE_DOUBLEHEIGHT_BOTTOM attribute.
      *                   This allows other parts of the code to work on the
      *                   assumption that all lines are the same height.
      *
@@ -608,13 +613,15 @@ private:
     //count - the number of characters on the line to copy
     //decoder - a decoder which converts terminal characters (an Character array) into text
     //appendNewLine - if true a new line character (\n) is appended to the end of the line
+    //isBlockSelectionMode - takes that in consideration while appending a new line.
     int  copyLineToStream(int line, int start, int count, TerminalCharacterDecoder *decoder,
-                          bool appendNewLine, const DecodingOptions options) const;
+                          bool appendNewLine, bool isBlockSelectionMode, const DecodingOptions options) const;
 
     //fills a section of the screen image with the character 'c'
     //the parameters are specified as offsets from the start of the screen image.
     //the loc(x,y) macro can be used to generate these values from a column,line pair.
-    void clearImage(int loca, int loce, char c);
+    //if resetLineRendition is true, all completely cleared lines will be set to single-width.
+    void clearImage(int loca, int loce, char c, bool resetLineRendition = true);
 
     //move screen image between 'sourceBegin' and 'sourceEnd' to 'dest'.
     //the parameters are specified as offsets from the start of the screen image.
@@ -651,11 +658,23 @@ private:
     // starting from 'startLine', where 0 is the first line in the history
     void copyFromHistory(Character *dest, int startLine, int count) const;
 
+    // Sets the text selection colors, either:
+    // - using reverseRendition(), which inverts the foreground/background
+    //   colors OR
+    // - setting the RE_BLEND_SELECTION_COLORS RenditionFlag, which will
+    //   blend the foreground/background colors
+    void setTextSelectionRendition(Character &ch) const;
+
     // returns a buffer that can hold at most 'count' characters,
     // where the number of reallocations and object reinitializations
     // should be as minimal as possible
     static Character *getCharacterBuffer(const int size);
 
+    // Returns if its app mode or not
+    inline bool isAppMode()
+    {
+        return _currentModes[MODE_AppScreen] == 1;
+    }
     // Get the cursor line after checking if its app mode or not
     int getCursorLine();
     // Set the cursor line after checking if its app mode or not
@@ -663,6 +682,10 @@ private:
 
     int getLineLength(const int line) const;
 
+    // returns the width in columns of the specified screen line,
+    // taking DECDWL/DECDHL (double width/height modes) into account.
+    int getScreenLineColumns(const int line) const;
+
     // screen image ----------------
     int _lines;
     int _columns;
@@ -680,10 +703,10 @@ private:
     bool _isResize;
     bool _enableReflowLines;
 
-    QVarLengthArray<LineProperty, 64> _lineProperties;
+    QVector<LineProperty> _lineProperties;
 
     // history buffer ---------------
-    HistoryScroll *_history;
+    std::unique_ptr<HistoryScroll> _history;
 
     // cursor location
     int _cuX;
@@ -742,7 +765,7 @@ private:
 
     // used in REP (repeating char)
     quint32 _lastDrawnChar;
-    EscapeSequenceUrlExtractor *_escapeSequenceUrlExtractor;
+    std::unique_ptr<EscapeSequenceUrlExtractor> _escapeSequenceUrlExtractor;
     void toggleUrlInput();
 
     // Vt102Emulation defined max argument value that can be passed to a Screen function
