@@ -1,25 +1,10 @@
 /*
-    This file is part of Konsole, a terminal emulator for KDE.
+    SPDX-FileCopyrightText: 2018-2019 Mariusz Glebocki <mglb@arccos-1.net>
+    SPDX-FileCopyrightText: 2018 Martin T. H. Sandsmark <martin.sandsmark@kde.org>
+    SPDX-FileCopyrightText: 2015-2018 Kurt Hindenburg <kurt.hindenburg@gmail.com>
+    SPDX-FileCopyrightText: 2005 Maksim Orlovich <maksim@kde.org>
 
-    Copyright 2018-2019 by Mariusz Glebocki <mglb@arccos-1.net>
-    Copyright 2018 by Martin T. H. Sandsmark <martin.sandsmark@kde.org>
-    Copyright 2015-2018 by Kurt Hindenburg <kurt.hindenburg@gmail.com>
-    Copyright 2005 by Maksim Orlovich <maksim@kde.org>
-
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301  USA.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 // Own
