@@ -1,20 +1,7 @@
 /*
-    Copyright 2008 by Robert Knight <robertknight@gmail.com>
+    SPDX-FileCopyrightText: 2008 Robert Knight <robertknight@gmail.com>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301  USA.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 // Own
@@ -60,7 +47,7 @@ void PartManualTest::testShortcutOverride()
     auto mainWindow = new KMainWindow();
     QMenu* fileMenu = mainWindow->menuBar()->addMenu(QStringLiteral("File"));
     QAction* testAction = fileMenu->addAction(QStringLiteral("Test"));
-    testAction->setShortcut(QKeySequence(Konsole::ACCEL + Qt::Key_S));
+    testAction->setShortcut(QKeySequence(Konsole::ACCEL | Qt::Key_S));
     connect(testAction, &QAction::triggered, this, &Konsole::PartManualTest::shortcutTriggered);
 
     // Create terminal part and embed in into the main window
