@@ -13,8 +13,10 @@
 #include <QDragEnterEvent>
 #include <QMimeData>
 #include <QApplication>
-#include <memory>
+#include <QStack>
 
+// C++
+#include <memory>
 
 // Konsole
 #include "widgets/ViewContainer.h"
@@ -23,6 +25,9 @@
 using Konsole::ViewSplitter;
 using Konsole::TerminalDisplay;
 
+bool ViewSplitter::m_drawTopLevelHandler;
+Qt::Orientation ViewSplitter::m_topLevelHandlerDrawnOrientation;
+
 //TODO: Connect the TerminalDisplay destroyed signal here.
 
 namespace {
@@ -106,12 +111,14 @@ void ViewSplitter::addTerminalDisplay(TerminalDisplay *terminalDisplay, Qt::Orie
         auto newSplitter = new ViewSplitter();
         TerminalDisplay *oldTerminalDisplay = splitter->activeTerminalDisplay();
         const int oldContainerIndex = splitter->indexOf(oldTerminalDisplay);
+        splitter->m_blockPropagatedDeletion = true;
         newSplitter->addWidget(behavior == AddBehavior::AddBefore ? terminalDisplay : oldTerminalDisplay);
         newSplitter->addWidget(behavior == AddBehavior::AddBefore ? oldTerminalDisplay : terminalDisplay);
         newSplitter->setOrientation(containerOrientation);
         newSplitter->updateSizes();
         newSplitter->show();
         splitter->insertWidget(oldContainerIndex, newSplitter);
+        splitter->m_blockPropagatedDeletion = false;
     }
     splitter->updateSizes();
 }
@@ -122,14 +129,26 @@ void ViewSplitter::childEvent(QChildEvent *event)
 
     if (event->removed()) {
         if (count() == 0) {
-            auto *parent_splitter = qobject_cast<ViewSplitter *>(parentWidget());
+            auto *parent_splitter = qobject_cast<ViewSplitter *>(parent());
             if (parent_splitter != nullptr) {
                 setParent(nullptr);
             }
             deleteLater();
-        }
-        if (findChild<TerminalDisplay*>() == nullptr) {
-            deleteLater();
+        } else if (count() == 1) {
+            if (!m_blockPropagatedDeletion) {
+                auto *parent_splitter = qobject_cast<ViewSplitter *>(parent());
+                if (parent_splitter) {
+                    parent_splitter->m_blockPropagatedDeletion = true;
+                    const auto sizes = parent_splitter->sizes();
+                    auto *wdg = widget(0);
+                    const int oldContainerIndex = parent_splitter->indexOf(this);
+                    parent_splitter->replaceWidget(oldContainerIndex, wdg);
+                    parent_splitter->m_blockPropagatedDeletion = false;
+                    parent_splitter->setSizes(sizes);
+                    wdg->setFocus();
+                    deleteLater();
+                }
+            }
         }
     }
 
@@ -368,3 +387,132 @@ void Konsole::ViewSplitter::showEvent(QShowEvent *)
     // Fixes lost focus in background mode.
     setFocusProxy(activeSplitter()->activeTerminalDisplay());
 }
+
+QPoint Konsole::ViewSplitter::mapToTopLevel(const QPoint& p)
+{
+    auto parentSplitter = qobject_cast<ViewSplitter*>(parent());
+    if (parentSplitter) {
+        auto next_pos = mapToParent(p);
+        return parentSplitter->mapToTopLevel(next_pos);
+    }
+    return p;
+}
+
+QPoint Konsole::ViewSplitter::mapFromTopLevel(const QPoint& p)
+{
+
+    auto parentSplitter = qobject_cast<ViewSplitter*>(parent());
+    if (parentSplitter) {
+        return mapFromParent(parentSplitter->mapFromTopLevel(p));
+    }
+    return p;
+}
+
+Konsole::ViewSplitterHandle::ViewSplitterHandle(Qt::Orientation orientation, QSplitter* parent)
+    : QSplitterHandle(orientation, parent)
+{
+}
+
+QSplitterHandle* ViewSplitter::createHandle()
+{
+    return new ViewSplitterHandle(orientation(), this);
+}
+
+namespace {
+    QList<int> allSplitterSizes;
+
+    int search_closest(const QList<int>& sorted_array, int x) {
+        if (sorted_array.isEmpty()) {
+            return -1;
+        }
+
+        auto iter_geq = std::lower_bound(
+            sorted_array.begin(),
+            sorted_array.end(),
+            x
+        );
+
+        if (iter_geq == sorted_array.begin()) {
+            return sorted_array[0];
+        }
+
+        int a = *(iter_geq - 1);
+        int b = *(iter_geq);
+
+        if (abs(x - a) < abs(x - b)) {
+            return a;
+        }
+
+        return b;
+    }
+}
+
+void Konsole::ViewSplitterHandle::mousePressEvent(QMouseEvent *ev)
+{
+    auto parentSplitter = qobject_cast<ViewSplitter*>(parentWidget());
+    auto topLevelSplitter = parentSplitter->getToplevelSplitter();
+
+    QList<ViewSplitter*> splitters = topLevelSplitter->findChildren<ViewSplitter*>();
+    splitters.append(topLevelSplitter);
+
+    for (auto splitter : splitters) {
+        if (splitter->orientation() != orientation()) {
+            continue;
+        }
+
+        int delta = 0;
+        for (auto point : splitter->sizes()) {
+            delta += point;
+            QPoint thisPoint = orientation() == Qt::Horizontal
+                ? QPoint(delta, 0)
+                : QPoint(0, delta);
+
+
+            QPoint splitterPos = splitter->mapToTopLevel(thisPoint);
+
+            const int ourPos = orientation() == Qt::Horizontal
+                ? splitterPos.x()
+                : splitterPos.y();
+
+            allSplitterSizes.push_back(ourPos);
+        }
+    }
+
+    std::sort(std::begin(allSplitterSizes), std::end(allSplitterSizes));
+
+    QPoint thisPoint = parentSplitter->mapToTopLevel(mapToParent(ev->pos()));
+    const int thisValue = search_closest(allSplitterSizes, orientation() == Qt::Horizontal ? thisPoint.x() : thisPoint.y());
+    allSplitterSizes.removeOne(thisValue);
+    { // context for the splitterSet temporary.
+        auto splitterSet = QSet<int>(std::begin(allSplitterSizes), std::end(allSplitterSizes));
+        allSplitterSizes = QList<int>(std::begin(splitterSet), std::end(splitterSet));
+    }
+    std::sort(std::begin(allSplitterSizes), std::end(allSplitterSizes));
+
+    QSplitterHandle::mousePressEvent(ev);
+}
+
+void Konsole::ViewSplitterHandle::mouseReleaseEvent(QMouseEvent *ev)
+{
+    allSplitterSizes.clear();
+    QSplitterHandle::mouseReleaseEvent(ev);
+}
+
+void Konsole::ViewSplitterHandle::mouseMoveEvent(QMouseEvent *ev)
+{
+    ViewSplitter *parentSplitter = qobject_cast<ViewSplitter*>(parentWidget());
+
+    QPoint thisPoint = parentSplitter->mapToTopLevel(mapToParent(ev->pos()));
+
+    const int thisValue = orientation() == Qt::Horizontal ? thisPoint.x() : thisPoint.y();
+    const int nearest = search_closest(allSplitterSizes, thisValue );
+    const int threshould = qAbs(nearest - thisValue);
+    if (threshould <= 20) {
+        auto *thisSplitter = qobject_cast<ViewSplitter*>(splitter());
+        QPoint localPoint = thisSplitter->mapFromTopLevel(orientation() == Qt::Horizontal ? QPoint(nearest, 0) : QPoint(0, nearest));
+        moveSplitter(orientation() == Qt::Horizontal ? localPoint.x() : localPoint.y());
+        return;
+    }
+
+    QSplitterHandle::mouseMoveEvent(ev);
+}
